# NetworkPort

The transport-layer port on which to access the service.  This can defined as,     - a single port within the range 0-65535 (max port)    - a range of ports, eg. 5000-5005 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**value** | **str** | The transport-layer port on which to access the service.  This can defined as,     - a single port within the range 0-65535 (max port)    - a range of ports, eg. 5000-5005  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


